/*
 *      tabwidget.cpp
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "tabwidget.h"
#include <QVBoxLayout>

TabWidget::TabWidget(QWidget *parent) :
    QWidget(parent)
{
    QVBoxLayout *mainLayout = new QVBoxLayout(this);
    m_splitter = new QSplitter(this);
    m_splitter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    m_navigation = new QListWidget(this);
    m_splitter->addWidget(m_navigation);
    m_switcher = new QStackedWidget(this);
    m_splitter->addWidget(m_switcher);
    m_splitter->setStretchFactor(0,2);
    m_splitter->setStretchFactor(1,17);
    mainLayout->addWidget(m_splitter);
    setLayout(mainLayout);
    connect(m_navigation, SIGNAL(currentRowChanged(int)), this, SLOT(slotRowChanged(int)));
}

void TabWidget::setTabTextColor(int index, const QColor &color)
{
    if(index>-1 && index<m_navigation->count()) m_navigation->item(index)->setForeground(QBrush(color));
}

QColor TabWidget::tabTextColor(int index) const
{
    if(index>-1 && index<m_navigation->count()) return m_navigation->item(index)->foreground().color();
    return QColor();
}

QWidget *TabWidget::currentWidget() const
{
    return m_switcher->currentWidget();
}

void TabWidget::setCurrentWidget(QWidget *widget)
{
    m_switcher->setCurrentWidget(widget);
}

int TabWidget::indexOf(QWidget *w) const
{
    return m_switcher->indexOf(w);
}

int TabWidget::currentIndex() const
{
    return m_switcher->currentIndex();
}

int TabWidget::count() const
{
    return m_switcher->count();
}

QWidget *TabWidget::widget(int index) const
{
    return m_switcher->widget(index);
}

QString TabWidget::tabText(int index) const
{
    if(index>-1 && index<m_navigation->count()) return m_navigation->item(index)->text();
    else return "";
}

void TabWidget::setTabText(int index, const QString &label)
{
    if(index>-1 && index<m_navigation->count()) m_navigation->item(index)->setText(label);
}

int TabWidget::addTab(QWidget *page, const QString &label)
{
    m_navigation->addItem(label);
    return m_switcher->addWidget(page);
}

int TabWidget::addTab(QWidget *page, const QIcon &icon, const QString &label)
{
    m_navigation->addItem(new QListWidgetItem(icon, label));
    return m_switcher->addWidget(page);
}

void TabWidget::setTabIcon(int index, const QIcon &icon)
{
    if(index>-1 && index<m_navigation->count()) m_navigation->item(index)->setIcon(icon);
}

void TabWidget::setCurrentIndex(int index)
{
    if(index>-1 && index<m_navigation->count())
    {
        m_navigation->setCurrentRow(index);
        m_switcher->setCurrentIndex(index);
    }
}

int TabWidget::insertTab(int index, QWidget *page, const QString &label)
{
    if(index>-1 && index<m_navigation->count())
    {
        setTabText(index, label);
        setTabIcon(index, QIcon());
    }
    else
    {
        m_navigation->insertItem(index, label);
    }
    return m_switcher->insertWidget(index, page);
}

int TabWidget::insertTab(int index, QWidget *page, const QIcon &icon, const QString &label)
{
    if(index>-1 && index<m_navigation->count())
    {
        setTabText(index, label);
        setTabIcon(index, icon);
    }
    else
    {
        m_navigation->insertItem(index, new QListWidgetItem(icon, label));
    }
    return m_switcher->insertWidget(index, page);
}

QIcon TabWidget::tabIcon(int index) const
{
    if(index>-1 && index<m_navigation->count()) return m_navigation->item(index)->icon();
    return QIcon();
}

void TabWidget::removeTab(int index)
{
    QListWidgetItem *i = m_navigation->takeItem(index);
    if(i) delete i;
    m_switcher->removeWidget(widget(index));
}

void TabWidget::slotRowChanged(int index)
{
    m_switcher->setCurrentIndex(index);
    emit currentChanged(index);
}
